use the tridiagonal matrix algorithm to solve a tridiagonal matrix
tridiagmatrix(L, D, U, b)vector of entries below the main diagonal
vector of entries on the main diagonal
vector of entries above the main diagonal
vector of the right-hand side of the linear system
the solution vector
tridiagmatrix uses the tridiagonal matrix algorithm to solve a
tridiagonal matrix.
Other linear: choleskymatrix,
detmatrix, gdls,
invmatrix, iterativematrix,
lumatrix, refmatrix,
rowops, vecnorm